rt2x00: Rename driver write_tx_datadesc callback function.

Now that the {usb,pci} specific write_tx_data functions are no longer
present we can rename the write_tx_datadesc callback function back to
its old name.

Signed-off-by: Gertjan van Wingerde <gwingerde@gmail.com>
Signed-off-by: Ivo van Doorn <IvDoorn@gmail.com>
Signed-off-by: John W. Linville <linville@tuxdriver.com>
diff --git a/drivers/net/wireless/rt2x00/rt2x00queue.c b/drivers/net/wireless/rt2x00/rt2x00queue.c
index b9cc253..5097fe0 100644
--- a/drivers/net/wireless/rt2x00/rt2x00queue.c
+++ b/drivers/net/wireless/rt2x00/rt2x00queue.c
@@ -430,10 +430,10 @@
 	memset(entry->skb->data, 0, rt2x00dev->ops->extra_tx_headroom);
 
 	/*
 	 * Call the driver's write_tx_datadesc function, if it exists.
 	 */
-	if (rt2x00dev->ops->lib->write_tx_datadesc)
-		rt2x00dev->ops->lib->write_tx_datadesc(entry, txdesc);
+	if (rt2x00dev->ops->lib->write_tx_data)
+		rt2x00dev->ops->lib->write_tx_data(entry, txdesc);
 
 	/*
 	 * Map the skb to DMA.
@@ -430,10 +430,10 @@
 
 	/*
-	 * Call the driver's write_tx_datadesc function, if it exists.
+	 * Call the driver's write_tx_data function, if it exists.
 	 */